@@ -116,16 +116,18 @@ class Gitlab:
 
         # We only support v4 API at this time
         if self._api_version not in ("4",):
-            raise ModuleNotFoundError(name=f"gitlab.v{self._api_version}.objects")
+            raise ModuleNotFoundError(f"gitlab.v{self._api_version}.objects")
         # NOTE: We must delay import of gitlab.v4.objects until now or
         # otherwise it will cause circular import errors
-        import gitlab.v4.objects
+        from gitlab.v4 import objects
 
-        objects = gitlab.v4.objects
         self._objects = objects
+        self.user: Optional[objects.CurrentUser] = None
 
         self.broadcastmessages = objects.BroadcastMessageManager(self)
         """See :class:`~gitlab.v4.objects.BroadcastMessageManager`"""
+        self.ci_lint = objects.CiLintManager(self)
+        """See :class:`~gitlab.v4.objects.CiLintManager`"""
         self.deploykeys = objects.DeployKeyManager(self)
         """See :class:`~gitlab.v4.objects.DeployKeyManager`"""
         self.deploytokens = objects.DeployTokenManager(self)
@@ -158,8 +160,12 @@ class Gitlab:
         """See :class:`~gitlab.v4.objects.NotificationSettingsManager`"""
         self.projects = objects.ProjectManager(self)
         """See :class:`~gitlab.v4.objects.ProjectManager`"""
+        self.registry_repositories = objects.RegistryRepositoryManager(self)
+        """See :class:`~gitlab.v4.objects.RegistryRepositoryManager`"""
         self.runners = objects.RunnerManager(self)
         """See :class:`~gitlab.v4.objects.RunnerManager`"""
+        self.runners_all = objects.RunnerAllManager(self)
+        """See :class:`~gitlab.v4.objects.RunnerManager`"""
         self.settings = objects.ApplicationSettingsManager(self)
         """See :class:`~gitlab.v4.objects.ApplicationSettingsManager`"""
         self.appearance = objects.ApplicationAppearanceManager(self)
@@ -208,12 +214,14 @@ class Gitlab:
         self.__dict__.update(state)
         # We only support v4 API at this time
         if self._api_version not in ("4",):
-            raise ModuleNotFoundError(name=f"gitlab.v{self._api_version}.objects")
+            raise ModuleNotFoundError(
+                f"gitlab.v{self._api_version}.objects"
+            )  # pragma: no cover, dead code currently
         # NOTE: We must delay import of gitlab.v4.objects until now or
         # otherwise it will cause circular import errors
-        import gitlab.v4.objects
+        from gitlab.v4 import objects
 
-        self._objects = gitlab.v4.objects
+        self._objects = objects
 
     @property
     def url(self) -> str:
@@ -395,6 +403,11 @@ class Gitlab:
         Returns:
             (True, []) if the file is valid, (False, errors(list)) otherwise
         """
+        utils.warn(
+            "`lint()` is deprecated and will be removed in a future version.\n"
+            "Please use `ci_lint.create()` instead.",
+            category=DeprecationWarning,
+        )
         post_data = {"content": content}
         data = self.http_post("/ci/lint", post_data=post_data, **kwargs)
         if TYPE_CHECKING:
@@ -482,9 +495,7 @@ class Gitlab:
         if (self.http_username and not self.http_password) or (
             not self.http_username and self.http_password
         ):
-            raise ValueError(
-                "Both http_username and http_password should " "be defined"
-            )
+            raise ValueError("Both http_username and http_password should be defined")
         if self.oauth_token and self.http_username:
             raise ValueError(
                 "Only one of oauth authentication or http "
@@ -512,7 +523,8 @@ class Gitlab:
                 self.http_username, self.http_password
             )
 
-    def enable_debug(self) -> None:
+    @staticmethod
+    def enable_debug() -> None:
         import logging
         from http.client import HTTPConnection  # noqa
 
@@ -531,7 +543,8 @@ class Gitlab:
             "verify": self.ssl_verify,
         }
 
-    def _get_base_url(self, url: Optional[str] = None) -> str:
+    @staticmethod
+    def _get_base_url(url: Optional[str] = None) -> str:
         """Return the base URL with the trailing slash stripped.
         If the URL is a Falsy value, return the default URL.
         Returns:
@@ -553,10 +566,10 @@ class Gitlab:
         """
         if path.startswith("http://") or path.startswith("https://"):
             return path
-        else:
-            return f"{self._url}{path}"
+        return f"{self._url}{path}"
 
-    def _check_redirects(self, result: requests.Response) -> None:
+    @staticmethod
+    def _check_redirects(result: requests.Response) -> None:
         # Check the requests history to detect 301/302 redirections.
         # If the initial verb is POST or PUT, the redirected request will use a
         # GET request, leading to unwanted behaviour.
@@ -581,8 +594,8 @@ class Gitlab:
                 )
             )
 
+    @staticmethod
     def _prepare_send_data(
-        self,
         files: Optional[Dict[str, Any]] = None,
         post_data: Optional[Union[Dict[str, Any], bytes]] = None,
         raw: bool = False,
@@ -803,11 +816,34 @@ class Gitlab:
         else:
             return result
 
+    def http_head(
+        self, path: str, query_data: Optional[Dict[str, Any]] = None, **kwargs: Any
+    ) -> requests.structures.CaseInsensitiveDict:
+        """Make a HEAD request to the Gitlab server.
+
+        Args:
+            path: Path or full URL to query ('/projects' or
+                        'http://whatever/v4/api/projecs')
+            query_data: Data to send as query parameters
+            **kwargs: Extra options to send to the server (e.g. sudo, page,
+                      per_page)
+        Returns:
+            A requests.header object
+        Raises:
+            GitlabHttpError: When the return code is not 2xx
+        """
+
+        query_data = query_data or {}
+        result = self.http_request("head", path, query_data=query_data, **kwargs)
+        return result.headers
+
     def http_list(
         self,
         path: str,
         query_data: Optional[Dict[str, Any]] = None,
-        as_list: Optional[bool] = None,
+        *,
+        as_list: Optional[bool] = None,  # Deprecated in favor of `iterator`
+        iterator: Optional[bool] = None,
         **kwargs: Any,
     ) -> Union["GitlabList", List[Dict[str, Any]]]:
         """Make a GET request to the Gitlab server for list-oriented queries.
@@ -816,13 +852,14 @@ class Gitlab:
             path: Path or full URL to query ('/projects' or
                         'http://whatever/v4/api/projects')
             query_data: Data to send as query parameters
+            iterator: Indicate if should return a generator (True)
             **kwargs: Extra options to send to the server (e.g. sudo, page,
                       per_page)
 
         Returns:
-            A list of the objects returned by the server. If `as_list` is
-            False and no pagination-related arguments (`page`, `per_page`,
-            `all`) are defined then a GitlabList object (generator) is returned
+            A list of the objects returned by the server. If `iterator` is
+            True and no pagination-related arguments (`page`, `per_page`,
+            `get_all`) are defined then a GitlabList object (generator) is returned
             instead. This object will make API calls when needed to fetch the
             next items from the server.
 
@@ -832,15 +869,35 @@ class Gitlab:
         """
         query_data = query_data or {}
 
-        # In case we want to change the default behavior at some point
-        as_list = True if as_list is None else as_list
+        # Don't allow both `as_list` and `iterator` to be set.
+        if as_list is not None and iterator is not None:
+            raise ValueError(
+                "Only one of `as_list` or `iterator` can be used. "
+                "Use `iterator` instead of `as_list`. `as_list` is deprecated."
+            )
+
+        if as_list is not None:
+            iterator = not as_list
+            utils.warn(
+                message=(
+                    f"`as_list={as_list}` is deprecated and will be removed in a "
+                    f"future version. Use `iterator={iterator}` instead."
+                ),
+                category=DeprecationWarning,
+            )
+
+        # Provide a `get_all`` param to avoid clashes with `all` API attributes.
+        get_all = kwargs.pop("get_all", None)
+
+        if get_all is None:
+            # For now, keep `all` without deprecation.
+            get_all = kwargs.pop("all", None)
 
-        get_all = kwargs.pop("all", None)
         url = self._build_url(path)
 
         page = kwargs.get("page")
 
-        if as_list is False:
+        if iterator:
             # Generator requested
             return GitlabList(self, url, query_data, **kwargs)
 
@@ -853,7 +910,7 @@ class Gitlab:
 
         def should_emit_warning() -> bool:
             # No warning is emitted if any of the following conditions apply:
-            # * `all=False` was set in the `list()` call.
+            # * `get_all=False` was set in the `list()` call.
             # * `page` was set in the `list()` call.
             # * GitLab did not return the `x-per-page` header.
             # * Number of items received is less than per-page value.
@@ -878,12 +935,12 @@ class Gitlab:
         total_items = "many" if gl_list.total is None else gl_list.total
         utils.warn(
             message=(
-                f"Calling a `list()` method without specifying `all=True` or "
-                f"`as_list=False` will return a maximum of {gl_list.per_page} items. "
+                f"Calling a `list()` method without specifying `get_all=True` or "
+                f"`iterator=True` will return a maximum of {gl_list.per_page} items. "
                 f"Your query returned {len(items)} of {total_items} items. See "
                 f"{_PAGINATION_URL} for more details. If this was done intentionally, "
                 f"then this warning can be supressed by adding the argument "
-                f"`all=False` to the `list()` call."
+                f"`get_all=False` to the `list()` call."
             ),
             category=UserWarning,
         )
@@ -927,6 +984,7 @@ class Gitlab:
             query_data=query_data,
             post_data=post_data,
             files=files,
+            raw=raw,
             **kwargs,
         )
         try:
