@@ -25,6 +25,7 @@ import gitlab
 import gitlab.base
 import gitlab.v4.objects
 from gitlab import cli
+from gitlab.exceptions import GitlabCiLintError
 
 
 class GitlabCLI:
@@ -133,6 +134,16 @@ class GitlabCLI:
         except Exception as e:  # pragma: no cover, cli.die is unit-tested
             cli.die("Impossible to download the export", e)
 
+    def do_validate(self) -> None:
+        if TYPE_CHECKING:
+            assert isinstance(self.mgr, gitlab.v4.objects.CiLintManager)
+        try:
+            self.mgr.validate(self.args)
+        except GitlabCiLintError as e:  # pragma: no cover, cli.die is unit-tested
+            cli.die("CI YAML Lint failed", e)
+        except Exception as e:  # pragma: no cover, cli.die is unit-tested
+            cli.die("Cannot validate CI YAML", e)
+
     def do_create(self) -> gitlab.base.RESTObject:
         if TYPE_CHECKING:
             assert isinstance(self.mgr, gitlab.mixins.CreateMixin)
@@ -229,7 +240,18 @@ def _populate_sub_parser_by_class(
 
             sub_parser_action.add_argument("--page", required=False, type=int)
             sub_parser_action.add_argument("--per-page", required=False, type=int)
-            sub_parser_action.add_argument("--all", required=False, action="store_true")
+            sub_parser_action.add_argument(
+                "--get-all",
+                required=False,
+                action="store_true",
+                help="Return all items from the server, without pagination.",
+            )
+            sub_parser_action.add_argument(
+                "--all",
+                required=False,
+                action="store_true",
+                help="Deprecated. Use --get-all instead.",
+            )
 
         if action_name == "delete":
             if cls._id_attr is not None:
@@ -355,7 +377,9 @@ def extend_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
 
     for cls in sorted(classes, key=operator.attrgetter("__name__")):
         arg_name = cli.cls_to_gitlab_resource(cls)
-        object_group = subparsers.add_parser(arg_name)
+        object_group = subparsers.add_parser(
+            arg_name, formatter_class=cli.VerticalHelpFormatter
+        )
 
         object_subparsers = object_group.add_subparsers(
             title="action",
