@@ -1,3 +1,7 @@
+"""
+GitLab API:
+https://docs.gitlab.com/ee/api/projects.html
+"""
 from typing import (
     Any,
     Callable,
@@ -34,6 +38,7 @@ from .audit_events import ProjectAuditEventManager  # noqa: F401
 from .badges import ProjectBadgeManager  # noqa: F401
 from .boards import ProjectBoardManager  # noqa: F401
 from .branches import ProjectBranchManager, ProjectProtectedBranchManager  # noqa: F401
+from .ci_lint import ProjectCiLintManager  # noqa: F401
 from .clusters import ProjectClusterManager  # noqa: F401
 from .commits import ProjectCommitManager  # noqa: F401
 from .container_registry import ProjectRegistryRepositoryManager  # noqa: F401
@@ -49,7 +54,10 @@ from .events import ProjectEventManager  # noqa: F401
 from .export_import import ProjectExportManager, ProjectImportManager  # noqa: F401
 from .files import ProjectFileManager  # noqa: F401
 from .hooks import ProjectHookManager  # noqa: F401
+from .integrations import ProjectIntegrationManager, ProjectServiceManager  # noqa: F401
+from .invitations import ProjectInvitationManager  # noqa: F401
 from .issues import ProjectIssueManager  # noqa: F401
+from .iterations import GroupIterationManager  # noqa: F401
 from .jobs import ProjectJobManager  # noqa: F401
 from .labels import ProjectLabelManager  # noqa: F401
 from .members import ProjectMemberAllManager, ProjectMemberManager  # noqa: F401
@@ -74,7 +82,6 @@ from .push_rules import ProjectPushRulesManager  # noqa: F401
 from .releases import ProjectReleaseManager  # noqa: F401
 from .repositories import RepositoryMixin
 from .runners import ProjectRunnerManager  # noqa: F401
-from .services import ProjectServiceManager  # noqa: F401
 from .snippets import ProjectSnippetManager  # noqa: F401
 from .statistics import (  # noqa: F401
     ProjectAdditionalStatisticsManager,
@@ -97,6 +104,8 @@ __all__ = [
     "ProjectRemoteMirrorManager",
     "ProjectStorage",
     "ProjectStorageManager",
+    "SharedProject",
+    "SharedProjectManager",
 ]
 
 
@@ -158,6 +167,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     badges: ProjectBadgeManager
     boards: ProjectBoardManager
     branches: ProjectBranchManager
+    ci_lint: ProjectCiLintManager
     clusters: ProjectClusterManager
     commits: ProjectCommitManager
     customattributes: ProjectCustomAttributeManager
@@ -172,8 +182,11 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     groups: ProjectGroupManager
     hooks: ProjectHookManager
     imports: ProjectImportManager
+    integrations: ProjectIntegrationManager
+    invitations: ProjectInvitationManager
     issues: ProjectIssueManager
     issues_statistics: ProjectIssuesStatisticsManager
+    iterations: GroupIterationManager
     jobs: ProjectJobManager
     keys: ProjectKeyManager
     labels: ProjectLabelManager
@@ -470,6 +483,21 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(data, dict)
         return {"alt": data["alt"], "url": data["url"], "markdown": data["markdown"]}
 
+    @cli.register_custom_action("Project")
+    @exc.on_http_error(exc.GitlabRestoreError)
+    def restore(self, **kwargs: Any) -> None:
+        """Restore a project marked for deletion.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabRestoreError: If the server failed to perform the request
+        """
+        path = f"/projects/{self.encoded_id}/restore"
+        self.manager.gitlab.http_post(path, **kwargs)
+
     @cli.register_custom_action("Project", optional=("wiki",))
     @exc.on_http_error(exc.GitlabGetError)
     def snapshot(
@@ -639,6 +667,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "jobs_enabled",
             "lfs_enabled",
             "merge_method",
+            "merge_pipelines_enabled",
             "merge_requests_access_level",
             "merge_requests_enabled",
             "mirror_trigger_builds",
@@ -663,6 +692,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "snippets_enabled",
             "squash_option",
             "tag_list",
+            "topics",
             "template_name",
             "template_project_id",
             "use_custom_template",
@@ -703,6 +733,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "jobs_enabled",
             "lfs_enabled",
             "merge_method",
+            "merge_pipelines_enabled",
             "merge_requests_access_level",
             "merge_requests_enabled",
             "mirror_overwrites_diverged_branches",
@@ -733,6 +764,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "squash_option",
             "suggestion_commit_message",
             "tag_list",
+            "topics",
             "visibility",
             "wiki_access_level",
             "wiki_enabled",
@@ -769,6 +801,7 @@ class ProjectManager(CRUDMixin, RESTManager):
     _types = {
         "avatar": types.ImageAttribute,
         "topic": types.CommaSeparatedListAttribute,
+        "topics": types.ArrayAttribute,
     }
 
     def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> Project:
@@ -1055,3 +1088,26 @@ class ProjectStorageManager(GetWithoutIdMixin, RESTManager):
 
     def get(self, **kwargs: Any) -> ProjectStorage:
         return cast(ProjectStorage, super().get(**kwargs))
+
+
+class SharedProject(RESTObject):
+    pass
+
+
+class SharedProjectManager(ListMixin, RESTManager):
+    _path = "/groups/{group_id}/projects/shared"
+    _obj_cls = SharedProject
+    _from_parent_attrs = {"group_id": "id"}
+    _list_filters = (
+        "archived",
+        "visibility",
+        "order_by",
+        "sort",
+        "search",
+        "simple",
+        "starred",
+        "with_issues_enabled",
+        "with_merge_requests_enabled",
+        "min_access_level",
+        "with_custom_attributes",
+    )
